==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnMovingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDescription } from "./WebColumnMovingEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEventArgsDescriptionMetadata.c(WebColumnMovingEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnMovingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnMovingEventArgsDescriptionMetadata.a);
            WebColumnMovingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnMovingEventArgs", () => new WebColumnMovingEventArgsDescription());
            a.z("WebColumnMovingEventArgs", WebColumnMovingEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEventArgsDescriptionMetadata, 'WebColumnMovingEventArgsDescriptionMetadata');
    WebColumnMovingEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnMovingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDescription } from "./WebColumnMovingEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEventArgsDescriptionMetadata.c(WebColumnMovingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnMovingEventArgsDescriptionMetadata.a);
            WebColumnMovingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnMovingEventArgs", () => new WebColumnMovingEventArgsDescription());
            a.ab("WebColumnMovingEventArgs", WebColumnMovingEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEventArgsDescriptionMetadata, 'WebColumnMovingEventArgsDescriptionMetadata');
    WebColumnMovingEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDescriptionMetadata;
})();
